<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it_IT">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../ui/AboutDialog.ui" line="14"/>
        <source>About Scan Tailor</source>
        <translation>a proposito di Scan Tailor</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="27"/>
        <source>About</source>
        <translation>a proposito di...</translation>
    </message>
    <message>
        <source>Scan Tailor is an interactive post-processing tool for scanned pages. It performs operations such as page splitting, skew correction, adding/removing margins, and others. You give it raw scans, and you get pages ready to be printed or assembled into a PDF or DJVU file.  Scanning and optical character recogrnition is out of scope of this project.</source>
        <translation type="obsolete">Scan Tailor è uno strumento di post-elaborazione per pagine scansionate. Effettua operazioni quali la suddivisione a metà delle pagine, la correzione dell&apos;angolatura, l&apos;aggiunta/rimozione dei margini, ed altro. Voi gli fornite una scansione grezza, e ne ottenete pagine pronte per essere assemblate in un PDF o in un file DJVU. La scansione ed il riconoscimento ottico dei caratteri esulano dallo scopo di questo progetto.</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="33"/>
        <source>Scan Tailor is an interactive post-processing tool for scanned pages. It performs operations such as page splitting, skew correction, adding/removing margins, and others. You give it raw scans, and you get pages ready to be printed or assembled into a PDF or DJVU file.  Scanning and optical character recognition is out of scope of this project.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="101"/>
        <source>Authors</source>
        <translation>Autori</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="125"/>
        <source>Lead Developer</source>
        <translation>Sviluppatore Capo</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="132"/>
        <source>Joseph Artsimovich</source>
        <translation>Joseph Artsimovich
</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="157"/>
        <source>U235 - Picture auto-detection algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="164"/>
        <source>Robert B. - First generation dewarping algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="171"/>
        <source>Andrey Bergman - System load adjustment.</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../ui/AboutDialog.ui" line="178"/>
        <source>Petr Kovář - Command line interface.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="205"/>
        <source>Svetoslav Sashkov, Mandor - Bulgarian</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../ui/AboutDialog.ui" line="212"/>
        <source>Petr Kovář - Czech</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="219"/>
        <source>Stefan Birkner - German</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="226"/>
        <source>Angelo Gemmi - Italian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="233"/>
        <source>Masahiro Kitagawa - Japanese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="240"/>
        <source>Patrick Pascal - French</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../ui/AboutDialog.ui" line="247"/>
        <source>Daniel Koć - Polish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="254"/>
        <source>Joseph Artsimovich - Russian</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <location filename="../ui/AboutDialog.ui" line="261"/>
        <source>Marián Hvolka - Slovak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="268"/>
        <source>Flavio Benelli - Spanish</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="275"/>
        <source>Davidson Wang - Traditional Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="282"/>
        <source>Yuri Chornoivan - Ukrainian</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="309"/>
        <source>denver 22</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="190"/>
        <source>Translators</source>
        <translation>Traduttori</translation>
    </message>
    <message>
        <source>Svetoslav Sashkov, Mandor - Bulgarian
               Stefan Birkner - German
               Angelo Gemmi - Italian
               Masahiro Kitagawa - Japanese
               Patrick Pascal - French
               Joseph Artsimovich - Russian
               Davidson Wang - Traditional Chinese</source>
        <translation type="obsolete">Svetoslav Sashkov, Mandor - Bulgarian
               Stefan Birkner - German
               Angelo Gemmi - Italian
               Masahiro Kitagawa - Japanese
               Patrick Pascal - French
               Joseph Artsimovich - Russian
               Davidson Wang - Traditional Chinese</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="142"/>
        <source>Contributors</source>
        <translation>Contributori</translation>
    </message>
    <message>
        <source>U235 - Picture auto-detection algorithm.
Robert B. - Dewarping algorithm.
Andrey Bergman - System load adjustment.
</source>
        <translation type="obsolete">U235 - Algoritmo di autorilevamento dell&apos;immagine.
Robert B. - Algoritmo di correzione deformazioni.
Andrey Bergman - regolazione carico di sistema.
</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="294"/>
        <source>Documentation</source>
        <translation>Documentazione</translation>
    </message>
    <message>
        <source>denver 22
phaedrus
Taxman</source>
        <translation type="obsolete">denver 22
phaedrus
Taxman</translation>
    </message>
    <message>
        <location filename="../ui/AboutDialog.ui" line="350"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
</context>
<context>
    <name>BatchProcessingLowerPanel</name>
    <message>
        <location filename="../ui/BatchProcessingLowerPanel.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/BatchProcessingLowerPanel.ui" line="36"/>
        <source>Beep when finished</source>
        <translation>Segnale sonoro ad operazione ultimata</translation>
    </message>
</context>
<context>
    <name>ColorPickupInteraction</name>
    <message>
        <location filename="../filters/output/ColorPickupInteraction.cpp" line="47"/>
        <source>Click on an area to pick up its color, or ESC to cancel.</source>
        <translation>Clicca su di un&apos;area per prelevarne il suo proprio colore, o ESC per cancellare.</translation>
    </message>
</context>
<context>
    <name>DeskewApplyDialog</name>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="20"/>
        <source>Apply to</source>
        <translation type="unfinished">Applica a</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="26"/>
        <source>This page only (already applied)</source>
        <translation type="unfinished">Solo questa pagina (già applicato)</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="36"/>
        <source>All pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="43"/>
        <source>This page and the following ones</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="59"/>
        <source>Selected pages</source>
        <translation type="unfinished">Pagine selezionate</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewApplyDialog.ui" line="92"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation type="unfinished">Usa Ctrl+Click / Shift+Click per selezionare più pagine.</translation>
    </message>
</context>
<context>
    <name>DeskewOptionsWidget</name>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="20"/>
        <source>Deskew</source>
        <translation>Raddrizza</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="41"/>
        <source>Auto</source>
        <translation>Automatico</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="57"/>
        <source>Manual</source>
        <translation>Manuale</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ui/DeskewOptionsWidget.ui" line="140"/>
        <source>Apply To ...</source>
        <translation type="unfinished">Applica a...</translation>
    </message>
</context>
<context>
    <name>DragHandler</name>
    <message>
        <location filename="../interaction/DragHandler.cpp" line="46"/>
        <source>Unrestricted dragging is possible by holding down the Shift key.</source>
        <translation>Il trascinamento libero è possibile tenendo premuto il tasto shift.</translation>
    </message>
</context>
<context>
    <name>FixDpiDialog</name>
    <message>
        <source>Need Fixing</source>
        <translation type="obsolete">Necessita correzione</translation>
    </message>
    <message>
        <source>All Pages</source>
        <translation type="obsolete">Tutte le pagine</translation>
    </message>
    <message>
        <source>DPI is too large and most likely wrong.</source>
        <translation type="obsolete">il DPI è eccessivo e probabilmente errato.</translation>
    </message>
    <message>
        <source>DPI is too small. Even if it&apos;s correct, you are not going to get acceptable results with it.</source>
        <translation type="obsolete">Il DPI è troppo basso. Anche se fosse corretto,non otterrete un risultato accettabile con un tale valore.</translation>
    </message>
    <message>
        <source>DPI is too small for this pixel size. Such combination would probably lead to out of memory errors.</source>
        <translation type="obsolete">Il DPI è troppo basso per pixel di queste dimensioni. Una simile combinazione potrebbe con tutta probabilità condurre ad errori di memoria esaurita.</translation>
    </message>
    <message>
        <source>%1 (page %2)</source>
        <translation type="obsolete">%1 (pagina %2)</translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="13"/>
        <source>Fix DPI</source>
        <translation>Correggi DPI</translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="23"/>
        <source>Tab 1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="33"/>
        <source>Tab 2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="46"/>
        <source>DPI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="69"/>
        <source>Custom</source>
        <translation>Personalizzato</translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="90"/>
        <source>x</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/FixDpiDialog.ui" line="113"/>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
</context>
<context>
    <name>FixDpiSinglePageDialog</name>
    <message>
        <source>Fix DPI</source>
        <translation type="obsolete">Correggi DPI</translation>
    </message>
    <message>
        <source>DPI for %1</source>
        <translation type="obsolete">DPI per %1</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="obsolete">Personalizzato</translation>
    </message>
    <message>
        <source>%1 (page %2)</source>
        <translation type="obsolete">%1 (pagina %2)</translation>
    </message>
    <message>
        <source>DPI is too large and most likely wrong.</source>
        <translation type="obsolete">Il DPI è eccessivo e probabilmente errato.</translation>
    </message>
    <message>
        <source>DPI is too small. Even if it&apos;s correct, you are not going to get acceptable results with it.</source>
        <translation type="obsolete">Il DPI è troppo basso. Anche se fosse corretto,non otterrete un risultato accettabile con un tale valore.</translation>
    </message>
    <message>
        <source>DPI is too small for this pixel size. Such combination would probably lead to out of memory errors.</source>
        <translation type="obsolete">Il DPI è troppo basso per pixel di queste dimensioni. Una simile combinazione potrebbe con tutta probabilità condurre ad errori di memoria esaurita.</translation>
    </message>
</context>
<context>
    <name>ImageViewBase</name>
    <message>
        <source>Use the mouse wheel or +/- to zoom.  When zoomed, dragging is possible.</source>
        <translation type="obsolete">Usa la rotellina del mouse o i tasti +/- per lo zoom. In fase di zoom, il trascinamento è possibile.</translation>
    </message>
    <message>
        <source>Unrestricted dragging is possible by holding down the Shift key.</source>
        <translation type="obsolete">Il trascinamento libero è possibile tenendo premuto il tasto shift.</translation>
    </message>
</context>
<context>
    <name>InteractiveXSpline</name>
    <message>
        <location filename="../interaction/InteractiveXSpline.cpp" line="47"/>
        <source>Click to create a new control point.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../interaction/InteractiveXSpline.cpp" line="73"/>
        <source>This point can be dragged.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../interaction/InteractiveXSpline.cpp" line="75"/>
        <source>Drag this point or delete it by pressing Del or D.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoadFileTask</name>
    <message>
        <source>The following file could not be loaded:
%1</source>
        <translation type="obsolete">Impossibile caricare il seguente file:
%1</translation>
    </message>
</context>
<context>
    <name>LoadFilesStatusDialog</name>
    <message>
        <location filename="../ui/LoadFilesStatusDialog.ui" line="14"/>
        <source>Some files failed to load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/LoadFilesStatusDialog.ui" line="27"/>
        <source>Loaded successfully: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/LoadFilesStatusDialog.ui" line="87"/>
        <source>Failed to load: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Beep when finished</source>
        <translation type="obsolete">Segnale sonoro ad operazione ultimata</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="232"/>
        <source>Save Project</source>
        <translation>Salva progetto</translation>
    </message>
    <message>
        <source>Save this project?</source>
        <translation type="obsolete">Salvo questo progetto?</translation>
    </message>
    <message>
        <source>Insert before ...</source>
        <translation type="obsolete">Inserisci prima...</translation>
    </message>
    <message>
        <source>Insert after ...</source>
        <translation type="obsolete">Inserisci dopo...</translation>
    </message>
    <message>
        <source>Remove from project ...</source>
        <translation type="obsolete">Rimuovi dal progetto...</translation>
    </message>
    <message>
        <source>Insert here ...</source>
        <translation type="obsolete">Inserisci qui ...</translation>
    </message>
    <message>
        <source>Scan Tailor Projects</source>
        <translation type="obsolete">Progetto Scan Tailor</translation>
    </message>
    <message>
        <source>Open Project</source>
        <translation type="obsolete">Apri progetto</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="obsolete">Errore</translation>
    </message>
    <message>
        <source>Unable to open the project file.</source>
        <translation type="obsolete">Impossibile aprire il file del progetto.</translation>
    </message>
    <message>
        <source>The project file is broken.</source>
        <translation type="obsolete">Il file del progetto è danneggiato.</translation>
    </message>
    <message>
        <source>Output is not yet possible, as the final size of pages is not yet known.
To determine it, run batch processing at &quot;Select Content&quot; or &quot;Margins&quot;.</source>
        <translation type="obsolete">Non è ancora possibile produrre i file di output, in quanto la dimensione finale delle pagine non è ancora nota.
Per determinarla, avvia l&apos;elaborazione automatica a &quot;Seleziona contenuto&quot; o &quot;Margini&quot;.</translation>
    </message>
    <message>
        <source>Output is not yet possible, as the final size of pages is not yet known.
To determine it, run batch processing at &quot;Select Content&quot; or &quot;Page Layout&quot;.</source>
        <translation type="obsolete">Non è ancora possibile produrre i file di output, in quanto la dimensione finale delle pagine non è ancora nota.
Per determinarla, avvia l&apos;elaborazione automatica a &quot; o &quot; Conformazione pagina&quot;.</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation type="obsolete">Senza nome</translation>
    </message>
    <message>
        <source>Error saving the project file!</source>
        <translation type="obsolete">Errore nel salvataggio del file del progetto!</translation>
    </message>
    <message>
        <source>File to insert</source>
        <translation type="obsolete">File da inserire</translation>
    </message>
    <message>
        <source>Images not in project (%1)</source>
        <translation type="obsolete">Immagini non nel progetto (%1)</translation>
    </message>
    <message>
        <source>Error opening the image file.</source>
        <translation type="obsolete">Errore nell&apos;apertura del file immagine.</translation>
    </message>
    <message>
        <source>%1 (page %2)</source>
        <translation type="obsolete">%1 (pagina %2)</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="obsolete">Rimuovi</translation>
    </message>
    <message>
        <source>Unable to delete file:
%1</source>
        <translation type="obsolete">Impossibile eliminare il file:
%1</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="20"/>
        <source>MainWindow</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="130"/>
        <source>Keep current page in view.</source>
        <translation>Tieni la pagina correnta in vista.</translation>
    </message>
    <message>
        <source>Use PgUp, PgDown or Q, W to navigate between pages.</source>
        <translation type="obsolete">Usa PgUp/PgDown o i tasti Q/W per navigare tra le pagine.</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="156"/>
        <source>Use Home, End, PgUp (or Q), PgDown (or W) to navigate between pages.</source>
        <translation>Usa Home, End, PgUp (o Q), PgDown (o W) per navigare tra le pagine.</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="185"/>
        <source>Tools</source>
        <translation>Strumenti</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="196"/>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="210"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation type="obsolete">Debug</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="227"/>
        <source>Debug Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="235"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="240"/>
        <source>Save Project As ...</source>
        <translation>Salva il progetto come...</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="245"/>
        <location filename="../ui/MainWindow.ui" line="294"/>
        <source>Next Page</source>
        <translation>Prossima pagina</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="248"/>
        <source>PgDown</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="256"/>
        <location filename="../ui/MainWindow.ui" line="283"/>
        <source>Previous Page</source>
        <translation>Pagina precedente</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="259"/>
        <source>PgUp</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="267"/>
        <source>New Project ...</source>
        <translation>Nuovo progetto...</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="270"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="275"/>
        <source>Open Project ...</source>
        <translation>Apri progetto...</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="278"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="286"/>
        <source>Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="297"/>
        <source>W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="305"/>
        <source>Close Project</source>
        <translation>Chiudi progetto</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="308"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="313"/>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="316"/>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="326"/>
        <source>First Page</source>
        <translation>Prima pagina</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="329"/>
        <source>Home</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="334"/>
        <source>Last Page</source>
        <translation>Ultima pagina</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="337"/>
        <source>End</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="342"/>
        <source>About</source>
        <translation>A proposito di...</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="347"/>
        <source>Fix DPI ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="352"/>
        <source>Relinking ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop batch processing</source>
        <translation type="obsolete">Arresta l&apos;elaborazione automatica</translation>
    </message>
    <message>
        <location filename="../ui/MainWindow.ui" line="321"/>
        <source>Settings ...</source>
        <translation>Impostazioni ...</translation>
    </message>
</context>
<context>
    <name>NewOpenProjectPanel</name>
    <message>
        <location filename="../ui/NewOpenProjectPanel.ui" line="19"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/NewOpenProjectPanel.ui" line="52"/>
        <source>New Project ...</source>
        <translation>Nuovo progetto...</translation>
    </message>
    <message>
        <location filename="../ui/NewOpenProjectPanel.ui" line="78"/>
        <source>Open Project ...</source>
        <translation>Apri progetto...</translation>
    </message>
    <message>
        <location filename="../ui/NewOpenProjectPanel.ui" line="103"/>
        <source>Recent Projects</source>
        <translation>Progetti recenti</translation>
    </message>
</context>
<context>
    <name>OrientationApplyDialog</name>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="17"/>
        <source>Fix Orientation</source>
        <translation>Correggi orientamento</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="23"/>
        <source>Apply to</source>
        <translation>Applica a</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="29"/>
        <source>This page only (already applied)</source>
        <translation>Solo questa pagina (già applicato)</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="39"/>
        <source>All pages</source>
        <translation>Tutte le pagine</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="46"/>
        <source>This page and the following ones</source>
        <translation>Questa pagina e le seguenti</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="71"/>
        <source>Every other page</source>
        <extracomment>All odd or even pages, depending on the current page being odd or even.</extracomment>
        <translation>Ogni altra pagina</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="101"/>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="206"/>
        <source>The current page will be included.</source>
        <translation>La pagina corrente sarà inmclusa.</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="125"/>
        <source>Selected pages</source>
        <translation>Pagine selezionate</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="155"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Usa Ctrl+Click / Shift+Click per selezionare più pagine.</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationApplyDialog.ui" line="176"/>
        <source>Every other selected page</source>
        <translation>Ogni altra pagina selezionata</translation>
    </message>
</context>
<context>
    <name>OrientationOptionsWidget</name>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="13"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="19"/>
        <source>Rotate</source>
        <translation>Ruota</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="40"/>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="56"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="142"/>
        <source>Reset</source>
        <translation>Resetta</translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="167"/>
        <source>Scope</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/fix_orientation/ui/OrientationOptionsWidget.ui" line="188"/>
        <source>Apply to ...</source>
        <translation>Applica a...</translation>
    </message>
</context>
<context>
    <name>OutOfMemoryDialog</name>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="14"/>
        <source>Out of memory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="37"/>
        <source>Out of Memory Situation in Scan Tailor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="70"/>
        <source>Possible reasons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="103"/>
        <source>Did you have to fix the DPI of your source images? Are you sure the values you entered were correct?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="123"/>
        <source>Sometimes your source images may have wrong DPI embedded into them. Scan Tailor tries to detect those, but it&apos;s not always easy to tell. You may need to check &quot;Fix DPI even if they look normal&quot; when creating a project and look into &quot;All pages&quot; tab in the &quot;Fix DPI&quot; dialog, which is also accessible from the Tools menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="143"/>
        <source>Is your output DPI set too high? Usually you don&apos;t need it higher than 600.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="174"/>
        <source>What can help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="204"/>
        <source>Fix your DPIs. Learn how to &lt;a href=&quot;http://vimeo.com/12524529&quot;&gt;estimate unknown DPIs&lt;/a&gt;.</source>
        <extracomment>Feel free to change the URL to a localized video / text tutorial.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="224"/>
        <source>If your hardware and operating system are 64-bit capable, consider switching to a 64-bit version of Scan Tailor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="244"/>
        <source>When working with grayscale images, make sure they are really grayscale. If they are actually color images that just happen to look grayscale, convert them to grayscale using some kind of batch image converter. This will both save memory and increase performance.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="264"/>
        <source>As a last resort, you can save some memory by making sure thumbnails are pre-created rather than created on demand. This can be done by slowly scrolling the thumbnail list all the way from top to bottom before starting any real work.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="295"/>
        <source>What won&apos;t help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="325"/>
        <source>Surprisingly, upgrading your RAM won&apos;t help here. The lack of RAM is compensated by the swap mechanism, which makes things slow, but keeps programs running. An out of memory situation means we ran out of memory address space, which has nothing to do with the amount of RAM you have. The only way to increase the memory address space is to go 64-bit hardware, 64-bit operating system and 64-bit Scan Tailor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="361"/>
        <source>Save Project</source>
        <translation type="unfinished">Salva progetto</translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="384"/>
        <source>Save Project As ...</source>
        <translation type="unfinished">Salva il progetto come...</translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="404"/>
        <source>Don&apos;t Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="421"/>
        <source>Project Saved Successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/OutOfMemoryDialog.ui" line="453"/>
        <source>Please note that while Scan Tailor tries to catch out-of-memory situations and give you the opportunity to save your project, it&apos;s not always possible. This time it succeeded, but the next time it might just crash.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OutputApplyColorsDialog</name>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="17"/>
        <source>Apply Mode</source>
        <translation>Modalità applica</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="23"/>
        <source>Apply to</source>
        <translation>Applica a</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="29"/>
        <source>This page only (already applied)</source>
        <translation>Solo questa pagina (già applicato)</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="39"/>
        <source>All pages</source>
        <translation>Tutte le pagine</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="46"/>
        <source>This page and the following ones</source>
        <translation>Questa pagina e le successive</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="62"/>
        <source>Selected pages</source>
        <translation>Pagine selezionate</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputApplyColorsDialog.ui" line="95"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Usa Ctrl+Click / Shift+Click per selezionare più pagine.</translation>
    </message>
</context>
<context>
    <name>OutputChangeDewarpingDialog</name>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="17"/>
        <source>Apply Dewarping Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="23"/>
        <source>Mode</source>
        <translation type="unfinished">Modalità</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="29"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="42"/>
        <source>Auto (experimental)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="49"/>
        <source>Manual</source>
        <translation type="unfinished">Manuale</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="59"/>
        <source>Scope</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="65"/>
        <source>This page only</source>
        <translation type="unfinished">Solo questa pagina</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="75"/>
        <source>All pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="82"/>
        <source>This page and the following ones</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="98"/>
        <source>Selected pages</source>
        <translation type="unfinished">Pagine selezionate</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDewarpingDialog.ui" line="131"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation type="unfinished">Usa Ctrl+Click / Shift+Click per selezionare più pagine.</translation>
    </message>
</context>
<context>
    <name>OutputChangeDpiDialog</name>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="17"/>
        <source>Apply Output Resolution</source>
        <translation>Applica risoluzione di uscita</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="23"/>
        <source>DPI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="68"/>
        <source>Scope</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="74"/>
        <source>This page only</source>
        <translation>Solo questa pagina</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="91"/>
        <source>This page and the following ones</source>
        <translation>Questa pagina e le successive</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="107"/>
        <source>Selected pages</source>
        <translation>Pagine selezionate</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="140"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Usa Ctrl+Click / Shift+Click per selezionare più pagine.</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputChangeDpiDialog.ui" line="84"/>
        <source>All pages</source>
        <translation>Tutte le pagine</translation>
    </message>
</context>
<context>
    <name>OutputOptionsWidget</name>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="20"/>
        <source>Output Resolution (DPI)</source>
        <translation>Risoluzione di uscita (DPI)</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="78"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="419"/>
        <source>Change ...</source>
        <translation>Cambia...</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="103"/>
        <source>Mode</source>
        <translation>Modalità</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="169"/>
        <source>White margins</source>
        <translation>Margini bianchi</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="176"/>
        <source>Equalize illumination</source>
        <translation>Equalizza illuminazione</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="361"/>
        <source>Dewarping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="444"/>
        <source>Depth perception</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="533"/>
        <source>No despeckling</source>
        <translation>No despeckling</translation>
    </message>
    <message>
        <source>Dewarp</source>
        <translation type="obsolete">Elimina curvatura</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="336"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="484"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="666"/>
        <source>Apply To ...</source>
        <translation>Applica a...</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="509"/>
        <source>Despeckling</source>
        <translation>Despeckling</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="558"/>
        <source>Cautious despeckling</source>
        <translation>Despeckling prudente</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="561"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="587"/>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="613"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="584"/>
        <source>Normal despeckling</source>
        <translation>НDespeckling normale</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="610"/>
        <source>Aggressive despeckling</source>
        <translation>Despeckling agressivo</translation>
    </message>
    <message>
        <source>Despeckle</source>
        <translation type="obsolete">Despeckle</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="274"/>
        <source>Thinner</source>
        <translation>Più sottile</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/OutputOptionsWidget.ui" line="306"/>
        <source>Thicker</source>
        <translation>Più spesso</translation>
    </message>
</context>
<context>
    <name>PageLayoutApplyDialog</name>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="20"/>
        <source>Apply to</source>
        <translation>Applica a</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="26"/>
        <source>This page only (already applied)</source>
        <translation>Solo questa pagina (già applicato)</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="36"/>
        <source>All pages</source>
        <translation>Tute le pagine</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="43"/>
        <source>This page and the following ones</source>
        <translation>Questa pagina e le successive</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="59"/>
        <source>Every other page</source>
        <extracomment>All odd or even pages, depending on the current page being odd or even.</extracomment>
        <translation type="unfinished">Ogni altra pagina</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="89"/>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="194"/>
        <source>The current page will be included.</source>
        <translation type="unfinished">La pagina corrente sarà inmclusa.</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="110"/>
        <source>Selected pages</source>
        <translation>Pagine selezionate</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="143"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Usa Ctrl+Click / Shift+Click per selezionare più pagine.</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutApplyDialog.ui" line="164"/>
        <source>Every other selected page</source>
        <translation type="unfinished">Ogni altra pagina selezionata</translation>
    </message>
</context>
<context>
    <name>PageLayoutOptionsWidget</name>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="20"/>
        <source>Margins</source>
        <translation>Margini</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="42"/>
        <source>Millimeters (mm)</source>
        <translation>Millimetri (mm)</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="47"/>
        <source>Inches (in)</source>
        <translation>Pollici (in)</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="87"/>
        <source>Top</source>
        <translation>Sopra</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="100"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="161"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="338"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="361"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="384"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="407"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="430"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="456"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="479"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="502"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="525"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="121"/>
        <source>Bottom</source>
        <translation>Sotto</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="138"/>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="185"/>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="244"/>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="580"/>
        <source>Apply To ...</source>
        <translation>Applica a...</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="269"/>
        <source>Alignment</source>
        <translation>Allineamento</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/ui/PageLayoutOptionsWidget.ui" line="293"/>
        <source>Match size with other pages</source>
        <translation>Riscontra dimensione con le altre pagine</translation>
    </message>
    <message>
        <source>Align with other pages</source>
        <translation type="obsolete">Allinea con le altre pagine</translation>
    </message>
    <message>
        <source>Go to the widest page.</source>
        <translation type="obsolete">Vai alla pagina più larga.</translation>
    </message>
    <message>
        <source>Widest Page</source>
        <translation type="obsolete">pagina più larga</translation>
    </message>
    <message>
        <source>Go to the tallest page.</source>
        <translation type="obsolete">Vai alla pagina più alta.</translation>
    </message>
    <message>
        <source>Tallest Page</source>
        <translation type="obsolete">Pagina più alta</translation>
    </message>
</context>
<context>
    <name>PageSplitModeDialog</name>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="17"/>
        <source>Split Pages</source>
        <translation>Dividi pagine</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="63"/>
        <source>Mode</source>
        <translation>Modalità</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="69"/>
        <source>Auto</source>
        <translation>Automatico</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="79"/>
        <source>Manual</source>
        <translation>Manuale</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="89"/>
        <source>Scope</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="95"/>
        <source>This page only</source>
        <translation>Solo questa pagina</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="112"/>
        <source>This page and the following ones</source>
        <translation>Questa pagina e le successive</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="128"/>
        <source>Selected pages</source>
        <translation>Pagine selezionate</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="161"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation>Usa Ctrl+Click / Shift+Click per selezionare più pagine.</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitModeDialog.ui" line="105"/>
        <source>All pages</source>
        <translation>Tutte le pagine</translation>
    </message>
</context>
<context>
    <name>PageSplitOptionsWidget</name>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="20"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="26"/>
        <source>Page Layout</source>
        <translation>Conformazione pagina</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="134"/>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="159"/>
        <source>Change ...</source>
        <translation>Cambia...</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="184"/>
        <source>Split Line</source>
        <translation>Linea di taglio</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="214"/>
        <source>Auto</source>
        <translation>Automatico</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ui/PageSplitOptionsWidget.ui" line="230"/>
        <source>Manual</source>
        <translation>Manuale</translation>
    </message>
    <message>
        <source>...</source>
        <translation type="obsolete">...</translation>
    </message>
</context>
<context>
    <name>PictureZonePropDialog</name>
    <message>
        <location filename="../filters/output/ui/PictureZonePropDialog.ui" line="14"/>
        <source>Zone Properties</source>
        <translation>Proprietà zona</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/PictureZonePropDialog.ui" line="20"/>
        <source>Subtract from all layers</source>
        <translation>Sottrai da tutti i livelli</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/PictureZonePropDialog.ui" line="27"/>
        <source>Add to auto layer</source>
        <translation>Aggiungi al livello automatico</translation>
    </message>
    <message>
        <location filename="../filters/output/ui/PictureZonePropDialog.ui" line="34"/>
        <source>Subtract from auto layer</source>
        <translation>Sottrai al livello automatico</translation>
    </message>
</context>
<context>
    <name>ProjectFilesDialog</name>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="20"/>
        <source>Input Directory</source>
        <translation>Cartella sorgente</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="43"/>
        <source>Output Directory</source>
        <translation>Cartella di destinazione</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="obsolete">Errore</translation>
    </message>
    <message>
        <source>No files in project!</source>
        <translation type="obsolete">Nessun file nel progetto!</translation>
    </message>
    <message>
        <source>Input directory is not set or doesn&apos;t exist.</source>
        <translation type="obsolete">La cartella sorgente non è impostata o non esiste.</translation>
    </message>
    <message>
        <source>Input and output directories can&apos;t be the same.</source>
        <translation type="obsolete">Le cartelle sorgenti e di destinazione, non possono essere le stesse.</translation>
    </message>
    <message>
        <source>Create Directory?</source>
        <translation type="obsolete">Creo cartella?</translation>
    </message>
    <message>
        <source>Output directory doesn&apos;t exist.  Create it?</source>
        <translation type="obsolete">La cartella di destinazione non esiste.  Devo crearla?</translation>
    </message>
    <message>
        <source>Unable to create output directory.</source>
        <translation type="obsolete">Impossibile creare la cartella di destinazione.</translation>
    </message>
    <message>
        <source>Output directory is not set or doesn&apos;t exist.</source>
        <translation type="obsolete">la cartella di destinazione non è impostata o non esiste.</translation>
    </message>
    <message>
        <source>Some of the files failed to load.
Either we don&apos;t support their format, or they are broken.
You should remove them from the project.</source>
        <translation type="obsolete">Alcuni dei file non si è riusciti a caricarli.
O il loro formato non è supportato oppure sono danneggiati.
È necessario rimuoverli dal progetto.</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="14"/>
        <source>Project Files</source>
        <translation>File del progetto</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="33"/>
        <location filename="../ui/ProjectFilesDialog.ui" line="52"/>
        <source>Browse</source>
        <translation>Sfoglia</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="64"/>
        <source>Files Not In Project</source>
        <translation>File non nel progetto</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="77"/>
        <location filename="../ui/ProjectFilesDialog.ui" line="159"/>
        <source>Select All</source>
        <translation>Seleziona tutto</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="102"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Add selected files to project.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0;
text-indent:0px;&quot;&gt;Aggiungi i file selezionati al progetto.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="108"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="115"/>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Remove selected files from project.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0;
text-indent:0px;&quot;&gt;Rimuovi i file selezionati dal progetto.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="121"/>
        <source>&lt;&lt;</source>
        <translation>&lt;&lt;</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="143"/>
        <source>Files In Project</source>
        <translation>File nel progetto</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="171"/>
        <source>Right to left layout (for Hebrew and Arabic)</source>
        <translation>Da destra a sinistra (per Ebraico e Arabo)</translation>
    </message>
    <message>
        <location filename="../ui/ProjectFilesDialog.ui" line="178"/>
        <source>Fix DPIs, even if they look OK</source>
        <translation>Correggi il DPI, anche se appare a posto</translation>
    </message>
</context>
<context>
    <name>ProjectOpeningContext</name>
    <message>
        <source>Error</source>
        <translation type="obsolete">Errore</translation>
    </message>
    <message>
        <source>Unable to interpret the project file.</source>
        <translation type="obsolete">Impossibile interpretare il file del progetto.</translation>
    </message>
</context>
<context>
    <name>RelinkingDialog</name>
    <message>
        <location filename="../ui/RelinkingDialog.ui" line="14"/>
        <source>Relinking</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/RelinkingDialog.ui" line="97"/>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/RelinkingDialog.ui" line="100"/>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
</context>
<context>
    <name>RemoveFileDialog</name>
    <message>
        <source>Remove File</source>
        <translation type="obsolete">Rimuovi file</translation>
    </message>
    <message>
        <source>Remove %1 from project?</source>
        <translation type="obsolete">Rimuovo %1 dal progetto?</translation>
    </message>
    <message>
        <source>Also delete the file from disk</source>
        <translation type="obsolete">Eliminali anche dal disco</translation>
    </message>
</context>
<context>
    <name>RemovePagesDialog</name>
    <message>
        <location filename="../ui/RemovePagesDialog.ui" line="14"/>
        <source>Remove Pages</source>
        <translation>Rimuovi pagine</translation>
    </message>
    <message>
        <location filename="../ui/RemovePagesDialog.ui" line="57"/>
        <source>Remove %1 page(s) from project?</source>
        <translation>Rimuovo %1 pagina(e) dal progetto?</translation>
    </message>
    <message>
        <location filename="../ui/RemovePagesDialog.ui" line="72"/>
        <source>Corresponding output files will be deleted, while input files will remain.</source>
        <translation>I corrispondenti file risultanti saranno eliminati, mantenuti invece quelli sorgenti.</translation>
    </message>
    <message>
        <source>Files will remain on disk</source>
        <translation type="obsolete">I file rimarrano sul disco</translation>
    </message>
</context>
<context>
    <name>SelectContentApplyDialog</name>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="17"/>
        <source>Select Content</source>
        <translation type="unfinished">Seleziona contenuto</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="23"/>
        <source>Apply to</source>
        <translation type="unfinished">Applica a</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="29"/>
        <source>This page only (already applied)</source>
        <translation type="unfinished">Solo questa pagina (già applicato)</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="39"/>
        <source>All pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="46"/>
        <source>This page and the following ones</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="71"/>
        <source>Every other page</source>
        <extracomment>All odd or even pages, depending on the current page being odd or even.</extracomment>
        <translation type="unfinished">Ogni altra pagina</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="101"/>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="206"/>
        <source>The current page will be included.</source>
        <translation type="unfinished">La pagina corrente sarà inmclusa.</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="125"/>
        <source>Selected pages</source>
        <translation type="unfinished">Pagine selezionate</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="155"/>
        <source>Use Ctrl+Click / Shift+Click to select multiple pages.</source>
        <translation type="unfinished">Usa Ctrl+Click / Shift+Click per selezionare più pagine.</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentApplyDialog.ui" line="176"/>
        <source>Every other selected page</source>
        <translation type="unfinished">Ogni altra pagina selezionata</translation>
    </message>
</context>
<context>
    <name>SelectContentOptionsWidget</name>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="13"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="19"/>
        <source>Content Box</source>
        <translation>Riquadro contenuto</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="38"/>
        <source>Auto</source>
        <translation>Automatico</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="54"/>
        <source>Manual</source>
        <translation>Manuale</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="83"/>
        <source>Scope</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/select_content/ui/SelectContentOptionsWidget.ui" line="104"/>
        <source>Apply to ...</source>
        <translation type="unfinished">Applica a...</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Compiled without OpenGL support.</source>
        <translation type="obsolete">Compilato con supporto OpenGL.</translation>
    </message>
    <message>
        <source>Your hardware / driver don&apos;t provide the necessary features.</source>
        <translation type="obsolete">Il tuo hardware/driver non supporta le caratteristiche necessarie.</translation>
    </message>
    <message>
        <location filename="../ui/SettingsDialog.ui" line="14"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../ui/SettingsDialog.ui" line="20"/>
        <source>Use 3D acceleration for user interface</source>
        <translation>Utilizza accelerazione 3D per l&apos;interfaccia utente</translation>
    </message>
</context>
<context>
    <name>StageListView</name>
    <message>
        <source>Launch batch processing</source>
        <translation type="obsolete">Lancia elaborazione automatica</translation>
    </message>
</context>
<context>
    <name>SystemLoadWidget</name>
    <message>
        <location filename="../ui/SystemLoadWidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/SystemLoadWidget.ui" line="23"/>
        <source>System load</source>
        <translation>Carico di sistema</translation>
    </message>
    <message>
        <location filename="../ui/SystemLoadWidget.ui" line="46"/>
        <location filename="../ui/SystemLoadWidget.ui" line="73"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <source>Minimal</source>
        <translation type="obsolete">Minimale</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="obsolete">Normale</translation>
    </message>
</context>
<context>
    <name>ThumbnailSequence</name>
    <message>
        <source>%1 (page %2)</source>
        <translation type="obsolete">%1 (pagina %2)</translation>
    </message>
</context>
<context>
    <name>ZoneContextMenuInteraction</name>
    <message>
        <location filename="../zones/ZoneContextMenuInteraction.cpp" line="275"/>
        <source>Properties</source>
        <translation>Proprietà</translation>
    </message>
    <message>
        <location filename="../zones/ZoneContextMenuInteraction.cpp" line="265"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../zones/ZoneContextMenuInteraction.cpp" line="249"/>
        <source>Delete confirmation</source>
        <translation>Conferma di eliminazione</translation>
    </message>
    <message>
        <location filename="../zones/ZoneContextMenuInteraction.cpp" line="249"/>
        <source>Really delete this zone?</source>
        <translation>Eliminare davvero questa zona?</translation>
    </message>
</context>
<context>
    <name>ZoneCreationInteraction</name>
    <message>
        <location filename="../zones/ZoneCreationInteraction.cpp" line="206"/>
        <source>Click to finish this zone.  ESC to cancel.</source>
        <translation>Clicca per terminare questa zona. ESC per cancellare.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneCreationInteraction.cpp" line="208"/>
        <source>Connect first and last points to finish this zone.  ESC to cancel.</source>
        <translation>Unisci il primo e l&apos;ultimo punto per completare la zona.  ESC per cancellare.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneCreationInteraction.cpp" line="211"/>
        <source>Zones need to have at least 3 points.  ESC to cancel.</source>
        <translation>Le zone devono avere almeno tre punti.  ESC per cancellare.</translation>
    </message>
</context>
<context>
    <name>ZoneDefaultInteraction</name>
    <message>
        <location filename="../zones/ZoneDefaultInteraction.cpp" line="45"/>
        <source>Drag the vertex.</source>
        <translation>Trascina il vertice.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneDefaultInteraction.cpp" line="46"/>
        <source>Click to create a new vertex here.</source>
        <translation>Clicca per creare un nuovo vertice qui.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneDefaultInteraction.cpp" line="47"/>
        <source>Right click to edit zone properties.</source>
        <translation>Click destro per modificare le proprietà della zona.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneDefaultInteraction.cpp" line="49"/>
        <source>Click to start creating a new picture zone.</source>
        <translation>Clicca per avviare la creazione di una nuova zona.</translation>
    </message>
</context>
<context>
    <name>ZonePropertiesDialog</name>
    <message>
        <source>Zone Properties</source>
        <translation type="obsolete">Proprietà zona</translation>
    </message>
    <message>
        <source>Subtract from all layers</source>
        <translation type="obsolete">Sottrai da tutti ilivelli</translation>
    </message>
    <message>
        <source>Add to auto layer</source>
        <translation type="obsolete">Aggiungi al livello automatico</translation>
    </message>
    <message>
        <source>Subtract from auto layer</source>
        <translation type="obsolete">Sottrai al livello automatico</translation>
    </message>
</context>
<context>
    <name>ZoneVertexDragInteraction</name>
    <message>
        <location filename="../zones/ZoneVertexDragInteraction.cpp" line="160"/>
        <source>Merge these two vertices.</source>
        <translation>Fondi questi due vertici.</translation>
    </message>
    <message>
        <location filename="../zones/ZoneVertexDragInteraction.cpp" line="162"/>
        <source>Move the vertex to one of its neighbors to merge them.</source>
        <translation>Sposta il vertice ad uno dei suoi vicini per fonderli.</translation>
    </message>
</context>
<context>
    <name>deskew::Filter</name>
    <message>
        <location filename="../filters/deskew/Filter.cpp" line="57"/>
        <source>Deskew</source>
        <translation>Raddrizza</translation>
    </message>
</context>
<context>
    <name>deskew::ImageView</name>
    <message>
        <location filename="../filters/deskew/ImageView.cpp" line="62"/>
        <source>Use Ctrl+Wheel to rotate or Ctrl+Shift+Wheel for finer rotation.</source>
        <translation>Usa Ctrl+rotellina per ruotare Ctrl+Shift+rotellina per una rotazione più accurata.</translation>
    </message>
    <message>
        <location filename="../filters/deskew/ImageView.cpp" line="65"/>
        <source>Drag this handle to rotate the image.</source>
        <translation>Trascina questo per ruotare l&apos;immagine.</translation>
    </message>
</context>
<context>
    <name>deskew::OptionsWidget</name>
    <message>
        <location filename="../filters/deskew/OptionsWidget.cpp" line="69"/>
        <source>Apply Deskew</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>fix_orientation::ApplyDialog</name>
    <message>
        <location filename="../filters/fix_orientation/ApplyDialog.cpp" line="53"/>
        <source>Can&apos;t do: more than one group is selected.</source>
        <translation type="unfinished">Impossibile effettuare l&apos;azione: più di un gruppo selezionato.</translation>
    </message>
</context>
<context>
    <name>fix_orientation::Filter</name>
    <message>
        <location filename="../filters/fix_orientation/Filter.cpp" line="64"/>
        <source>Fix Orientation</source>
        <translation>Correggi orientamento</translation>
    </message>
</context>
<context>
    <name>output::ChangeDpiDialog</name>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="72"/>
        <source>Custom</source>
        <translation>Personalizzato</translation>
    </message>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="131"/>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="140"/>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="148"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="132"/>
        <source>DPI is not set.</source>
        <translation>НIl DPI non è impostato.</translation>
    </message>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="141"/>
        <source>DPI is too low!</source>
        <translation>Il DPI è troppo basso!</translation>
    </message>
    <message>
        <location filename="../filters/output/ChangeDpiDialog.cpp" line="149"/>
        <source>DPI is too high!</source>
        <translation>Il DPI è troppo alto!</translation>
    </message>
</context>
<context>
    <name>output::FillZoneEditor</name>
    <message>
        <location filename="../filters/output/FillZoneEditor.cpp" line="226"/>
        <source>Pick color</source>
        <translation>Seleziona colore</translation>
    </message>
</context>
<context>
    <name>output::Filter</name>
    <message>
        <location filename="../filters/output/Filter.cpp" line="63"/>
        <source>Output</source>
        <translation>Output</translation>
    </message>
</context>
<context>
    <name>output::OptionsWidget</name>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="63"/>
        <source>Black and White</source>
        <translation>Bianco e nero</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="64"/>
        <source>Color / Grayscale</source>
        <translation>Colore / Scala di grigi</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="65"/>
        <source>Mixed</source>
        <translation>Misto</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="407"/>
        <source>Apply Despeckling Level</source>
        <translation>Applica livello di despeckling</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="487"/>
        <source>Apply Depth Perception</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="660"/>
        <source>Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="663"/>
        <source>Auto</source>
        <translation type="unfinished">Automatico</translation>
    </message>
    <message>
        <location filename="../filters/output/OptionsWidget.cpp" line="666"/>
        <source>Manual</source>
        <translation type="unfinished">Manuale</translation>
    </message>
</context>
<context>
    <name>output::Task::UiUpdater</name>
    <message>
        <location filename="../filters/output/Task.cpp" line="506"/>
        <source>Picture zones are only available in Mixed mode.</source>
        <translation>Le zone immagini sonop disponibili solo nella  modalità mista.</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="558"/>
        <source>Despeckling can&apos;t be done in Color / Grayscale mode.</source>
        <translation>Il despeckling non può essere attuato in modalità colore / scala di grigi.</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="575"/>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="576"/>
        <source>Picture Zones</source>
        <translation>Zone immagini</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="577"/>
        <source>Fill Zones</source>
        <translation>Zone di riempimento</translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="578"/>
        <source>Dewarping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/output/Task.cpp" line="579"/>
        <source>Despeckling</source>
        <translation>Despeckling</translation>
    </message>
</context>
<context>
    <name>page_layout::ApplyDialog</name>
    <message>
        <location filename="../filters/page_layout/ApplyDialog.cpp" line="51"/>
        <source>Can&apos;t do: more than one group is selected.</source>
        <translation type="unfinished">Impossibile effettuare l&apos;azione: più di un gruppo selezionato.</translation>
    </message>
</context>
<context>
    <name>page_layout::Filter</name>
    <message>
        <source>Page Layout</source>
        <translation type="obsolete">Conformazione pagina</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/Filter.cpp" line="67"/>
        <source>Natural order</source>
        <translation>Ordine naturale</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/Filter.cpp" line="68"/>
        <source>Order by increasing width</source>
        <translation>Ordina per larghezza crescente</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/Filter.cpp" line="69"/>
        <source>Order by increasing height</source>
        <translation>Ordina per altezza crescente</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/Filter.cpp" line="79"/>
        <source>Margins</source>
        <translation>Margini</translation>
    </message>
</context>
<context>
    <name>page_layout::ImageView</name>
    <message>
        <location filename="../filters/page_layout/ImageView.cpp" line="76"/>
        <source>Resize margins by dragging any of the solid lines.</source>
        <translation>Ridimensiona margini utilizzando una delle linee continue.</translation>
    </message>
</context>
<context>
    <name>page_layout::OptionsWidget</name>
    <message>
        <location filename="../filters/page_layout/OptionsWidget.cpp" line="310"/>
        <source>Apply Margins</source>
        <translation>Applica margini</translation>
    </message>
    <message>
        <location filename="../filters/page_layout/OptionsWidget.cpp" line="325"/>
        <source>Apply Alignment</source>
        <translation>Applica allineamento</translation>
    </message>
</context>
<context>
    <name>page_split::Filter</name>
    <message>
        <location filename="../filters/page_split/Filter.cpp" line="65"/>
        <source>Natural order</source>
        <translation type="unfinished">Ordine naturale</translation>
    </message>
    <message>
        <location filename="../filters/page_split/Filter.cpp" line="66"/>
        <source>Order by split type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../filters/page_split/Filter.cpp" line="76"/>
        <source>Split Pages</source>
        <translation>Dividi pagine</translation>
    </message>
</context>
<context>
    <name>page_split::ImageView</name>
    <message>
        <source>Drag this handle to skew the line.</source>
        <translation type="obsolete">Trascina questa maniglia per deformare la linea.</translation>
    </message>
    <message>
        <source>This line can be dragged.</source>
        <translation type="obsolete">Questa linea può essere trascinata.</translation>
    </message>
    <message>
        <location filename="../filters/page_split/ImageView.cpp" line="85"/>
        <source>Drag the line or the handles.</source>
        <translation>Trascinare la linea o le maniglie.</translation>
    </message>
</context>
<context>
    <name>page_split::OptionsWidget</name>
    <message>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="116"/>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="208"/>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="301"/>
        <source>Set manually</source>
        <translation>Imposta manualmente</translation>
    </message>
    <message>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="165"/>
        <location filename="../filters/page_split/OptionsWidget.cpp" line="298"/>
        <source>Auto detected</source>
        <translation>Rilevato automaticamente</translation>
    </message>
</context>
<context>
    <name>page_split::UnremoveButton</name>
    <message>
        <location filename="../filters/page_split/UnremoveButton.cpp" line="38"/>
        <source>Restore removed page.</source>
        <translation>Ripristina pagina rimossa.</translation>
    </message>
</context>
<context>
    <name>select_content::ApplyDialog</name>
    <message>
        <location filename="../filters/select_content/ApplyDialog.cpp" line="53"/>
        <source>Can&apos;t do: more than one group is selected.</source>
        <translation type="unfinished">Impossibile effettuare l&apos;azione: più di un gruppo selezionato.</translation>
    </message>
</context>
<context>
    <name>select_content::Filter</name>
    <message>
        <location filename="../filters/select_content/Filter.cpp" line="59"/>
        <source>Natural order</source>
        <translation>Ordine naturale</translation>
    </message>
    <message>
        <location filename="../filters/select_content/Filter.cpp" line="60"/>
        <source>Order by increasing width</source>
        <translation>Ordina per larghezza crescente</translation>
    </message>
    <message>
        <location filename="../filters/select_content/Filter.cpp" line="61"/>
        <source>Order by increasing height</source>
        <translation>Ordina per altezza crescente</translation>
    </message>
    <message>
        <location filename="../filters/select_content/Filter.cpp" line="71"/>
        <source>Select Content</source>
        <translation>Seleziona contenuto</translation>
    </message>
</context>
<context>
    <name>select_content::ImageView</name>
    <message>
        <location filename="../filters/select_content/ImageView.cpp" line="58"/>
        <source>Use the context menu to enable / disable the content box.</source>
        <translation>Usa il menu contestuale per abilitar/disabilitare il riquadro contenuto.</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ImageView.cpp" line="61"/>
        <source>Drag lines or corners to resize the content box.</source>
        <translation>Trascina le linee o o bordi per ridimensionare il riquadro contenuto.</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ImageView.cpp" line="107"/>
        <source>Create Content Box</source>
        <translation>Crea riquadro contenuto</translation>
    </message>
    <message>
        <location filename="../filters/select_content/ImageView.cpp" line="108"/>
        <source>Remove Content Box</source>
        <translation>Rimuovi riquadro contenuto</translation>
    </message>
</context>
</TS>
